@@ -35,9 +35,9 @@
 #' @export
 estimate_pcf_fast <- function(pattern, ...){
 
-  k_fun <- suppressMessages(spatstat::Kest(X = pattern, ...)) # estimate K-fct
+  k_fun <- suppressMessages(spatstat.core::Kest(X = pattern, ...)) # estimate K-fct
 
-  result <- spatstat::pcf.fv(X = k_fun, ...) # estimate pcf from K-fct
+  result <- spatstat.core::pcf.fv(X = k_fun, ...) # estimate pcf from K-fct
 
   return(result)
 }
